@@ -1,11 +1,11 @@
-from dataclasses import dataclass, field
+from dataclasses import dataclass
 
 from lms.titleconfig.definitions.value import ValueDefinition
 
 
 @dataclass(frozen=True)
 class AttributeConfig:
-    """Class that represents an attribute config definition"""
+    """Class that represents an attribute config definition."""
 
     name: str
     description: str
